@@ -7,10 +7,10 @@
 
 #include "../src/decorationbutton.h"
 
-class MockButton : public KDecoration2::DecorationButton
+class MockButton : public KDecoration3::DecorationButton
 {
     Q_OBJECT
 public:
-    MockButton(KDecoration2::DecorationButtonType type, KDecoration2::Decoration *decoration, QObject *parent = nullptr);
-    void paint(QPainter *painter, const QRect &repaintRegion) override;
+    MockButton(KDecoration3::DecorationButtonType type, KDecoration3::Decoration *decoration, QObject *parent = nullptr);
+    void paint(QPainter *painter, const QRectF &repaintRegion) override;
 };
