@@ -55,4 +55,10 @@ private:
     Decoration *q;
 };
 
+class PositionerData : public QSharedData
+{
+public:
+    QRectF anchorRect;
+};
+
 } // namespace
